@@ -24,12 +24,3 @@ skip_if_skipped
 
 $top_srcdir/podcheck.pl "$srcdir/virt-cat.pod" virt-cat \
                         --path $top_srcdir/common/options
-$top_srcdir/podcheck.pl "$srcdir/virt-filesystems.pod" virt-filesystems \
-                        --path $top_srcdir/common/options
-$top_srcdir/podcheck.pl "$srcdir/virt-log.pod" virt-log \
-                        --path $top_srcdir/common/options
-$top_srcdir/podcheck.pl "$srcdir/virt-ls.pod" virt-ls \
-                        --path $top_srcdir/common/options \
-                        --ignore=--checksums,--extra-stat,--time,--uid
-$top_srcdir/podcheck.pl "$srcdir/virt-tail.pod" virt-tail \
-                        --path $top_srcdir/common/options
