@@ -44,6 +44,7 @@
 #include "options.h"
 #include "display-options.h"
 #include "libxml2-writer-macros.h"
+#include "utils.h"
 
 /* Currently open libguestfs handle. */
 guestfs_h *g;
@@ -586,19 +587,25 @@ output_filesystems (xmlTextWriterPtr xo, char *root)
 
   start_element ("filesystems") {
     for (i = 0; filesystems[i] != NULL; ++i) {
-      str = guestfs_canonical_device_name (g, filesystems[i]);
-      if (!str)
+      CLEANUP_FREE char *dev =
+        guestfs_canonical_device_name (g, filesystems[i]);
+      if (!dev)
         exit (EXIT_FAILURE);
 
       start_element ("filesystem") {
-        attribute ("dev", str);
-        free (str);
+        attribute ("dev", dev);
 
         guestfs_push_error_handler (g, NULL, NULL);
 
         str = guestfs_vfs_type (g, filesystems[i]);
-        if (str && str[0])
-          single_element ("type", str);
+        if (str && str[0]) {
+          const char *version = get_filesystem_version (g, dev, str);
+          start_element ("type") {
+            if (version)
+              attribute ("version", version);
+            string (str);
+          } end_element ();
+        }
         free (str);
 
         str = guestfs_vfs_label (g, filesystems[i]);
